==> vue-icon-saas-3.8.0.tgz: package/lib/language.js <==
import { svg } from "@xmweb-ui/vue-common";
import { openBlock, createElementBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 1024 1024",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024a512 512 0 1 1 512-512 512 512 0 0 1-512 512zm0-960a448 448 0 1 0 448 448A448 448 0 0 0 512 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024c-145.28 0-256-224-256-512S366.72 0 512 0s259.2 224 259.2 512-113.92 512-259.2 512zm0-960c-94.08 0-192 181.76-192 448s97.92 448 192 448 195.2-179.2 195.2-448S606.08 64 512 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 339.84a778.88 778.88 0 0 1-390.4-90.88A32 32 0 1 1 154.24 192 723.2 723.2 0 0 0 512 275.84a733.44 733.44 0 0 0 352.64-78.08A32 32 0 1 1 896 256a794.88 794.88 0 0 1-384 83.84zM880.64 822.4a30.72 30.72 0 0 1-16.64-4.48A723.2 723.2 0 0 0 506.24 736a733.44 733.44 0 0 0-352.64 78.72 32 32 0 0 1-32-55.68 802.56 802.56 0 0 1 384-87.04A790.4 790.4 0 0 1 896 762.88a32 32 0 0 1-16.64 59.52zM989.44 544H34.56a32 32 0 1 1 0-64h954.88a32 32 0 0 1 0 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_5 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024a32 32 0 0 1-32-32V34.56a32 32 0 1 1 64 0v954.88a32 32 0 0 1-32 34.56z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_6 = [_hoisted_2, _hoisted_3, _hoisted_4, _hoisted_5];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, _hoisted_6);
}
var Language = {
  render
};
var IconLanguage = svg({
  name: "IconLanguage",
  component: Language
});
export {
  IconLanguage as default
};

==> vue-icon-saas-3.22.1.tgz: package/lib/language.js <==
import { svg } from "@opentinyvue/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 1024 1024",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024a512 512 0 1 1 512-512 512 512 0 0 1-512 512zm0-960a448 448 0 1 0 448 448A448 448 0 0 0 512 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024c-145.28 0-256-224-256-512S366.72 0 512 0s259.2 224 259.2 512-113.92 512-259.2 512zm0-960c-94.08 0-192 181.76-192 448s97.92 448 192 448 195.2-179.2 195.2-448S606.08 64 512 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 339.84a778.88 778.88 0 0 1-390.4-90.88A32 32 0 1 1 154.24 192 723.2 723.2 0 0 0 512 275.84a733.44 733.44 0 0 0 352.64-78.08A32 32 0 1 1 896 256a794.88 794.88 0 0 1-384 83.84zM880.64 822.4a30.72 30.72 0 0 1-16.64-4.48A723.2 723.2 0 0 0 506.24 736a733.44 733.44 0 0 0-352.64 78.72 32 32 0 0 1-32-55.68 802.56 802.56 0 0 1 384-87.04A790.4 790.4 0 0 1 896 762.88a32 32 0 0 1-16.64 59.52zM989.44 544H34.56a32 32 0 1 1 0-64h954.88a32 32 0 0 1 0 64z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_5 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M512 1024a32 32 0 0 1-32-32V34.56a32 32 0 1 1 64 0v954.88a32 32 0 0 1-32 34.56z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_6 = [_hoisted_2, _hoisted_3, _hoisted_4, _hoisted_5];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_6));
}
var Language = {
  render
};
var index = function index2() {
  return svg({
    name: "IconLanguage",
    component: Language
  })();
};
export {
  index as default
};
